==> haskell-hjsmin-0.2.0.2-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hjsmin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsmin
version: 0.2.0.2
id: hjsmin-0.2.0.2-Cpv7xEf0i9KKNT2fqyKcJ1
key: hjsmin-0.2.0.2-Cpv7xEf0i9KKNT2fqyKcJ1
license: BSD3
maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
stability: unstable
homepage: http://github.com/erikd/hjsmin
synopsis: Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.
category: Web
author: Alan Zimmerman <alan.zimm@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Text.Jasmine
hidden-modules: Text.Jasmine.Pretty
abi: 75cf7948f3af4759d4fe926b7b0fb711
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hjsmin-0.2.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/hjsmin-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/hjsmin-0.2.0.2
hs-libraries: HShjsmin-0.2.0.2-Cpv7xEf0i9KKNT2fqyKcJ1
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj containers-0.5.10.2
    language-javascript-0.6.0.10-LnBBV4qA1wd7AOQPiej7Id
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             blaze-builder-0.4.0.2-ClyQj7ny9rnJd2QFCbHKRH=efe227a7a23c0583e6a2d74f96c7367f
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             language-javascript-0.6.0.10-LnBBV4qA1wd7AOQPiej7Id=5e6ab49700fce30521b864a48f7fcd09
haddock-interfaces: /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html: /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hjsmin-0.2.0.2-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hjsmin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsmin
version: 0.2.0.2
id: hjsmin-0.2.0.2-I7v6dqYFxCqBcgfpl1wxvf
key: hjsmin-0.2.0.2-I7v6dqYFxCqBcgfpl1wxvf
license: BSD3
maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
stability: unstable
homepage: http://github.com/erikd/hjsmin
synopsis: Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.
category: Web
author: Alan Zimmerman <alan.zimm@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Text.Jasmine
hidden-modules: Text.Jasmine.Pretty
abi: 8b91b7e395042d2d7bda85797cf3ebb4
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hjsmin-0.2.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/hjsmin-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/hjsmin-0.2.0.2
hs-libraries: HShjsmin-0.2.0.2-I7v6dqYFxCqBcgfpl1wxvf
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj containers-0.5.10.2
    language-javascript-0.6.0.10-GmTVSq4x72F2jSjDY0dv9m
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             blaze-builder-0.4.0.2-DHYoGQYzHva8PydFQisCY7=3962b4cebc9bc66ccf8167322740d159
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             language-javascript-0.6.0.10-GmTVSq4x72F2jSjDY0dv9m=b753263eadc451c0b180353c728703c2
haddock-interfaces: /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html: /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
